@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: IunoSettings.py 11221 2018-09-02 04:41:14Z Lavender $
+# $Id: IunoSettings.py 11266 2018-11-23 05:43:43Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-09-02 12:41:14 +0800 (Sun, 02 Sep 2018) $
-# $Revision: 11221 $
+# $Author: Kevin $ (last)
+# $Date: 2018-11-23 14:43:43 +0900 (週五, 23 十一月 2018) $
+# $Revision: 11266 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -54,7 +54,7 @@ DATABASES = {
 }
 
 TIME_ZONE = 'Asia/Taipei' #'America/Chicago'
-LANGUAGE_CODE = 'zh-TW' #'en-us'
+LANGUAGE_CODE = 'zh-Hant' #'en-us'
 USE_I18N = True
 LANGUAGES = (
   ('zh-tw', 'Traditional Chinese'),
