@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11219 2018-09-02 02:27:32Z Lavender $
+# $Id: __init__.py 11270 2018-11-29 01:56:59Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-09-02 10:27:32 +0800 (Sun, 02 Sep 2018) $
-# $Revision: 11219 $
+# $Author: Kevin $ (last)
+# $Date: 2018-11-29 10:56:59 +0900 (週四, 29 十一月 2018) $
+# $Revision: 11270 $
 
 from __future__ import print_function
 
@@ -718,6 +718,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'IUNO_CLOUD_BROWSER_SETTINGS': None,
         'IUNO_CLOUD_LOGGING_FILE': None,
         'IUNO_CLOUD_LOGGING_LEVEL': 'DEBUG' if DEBUG else 'INFO',
+        'IUNO_CLOUD_STORAGE_SETTINGS': None
     }
 
     update(settingsDict, iunoCloudDefaults)
