@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Service.py 11262 2018-11-16 06:29:44Z Kevin $
+# $Id: Service.py 11270 2018-11-29 01:56:59Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2018-11-16 14:29:44 +0800 (Fri, 16 Nov 2018) $
-# $Revision: 11262 $
+# $Date: 2018-11-29 10:56:59 +0900 (週四, 29 十一月 2018) $
+# $Revision: 11270 $
 
 import os
 import httplib2
@@ -21,13 +21,20 @@ import httplib2
 from apiclient import discovery
 from oauth2client import client, tools
 from oauth2client.file import Storage
-
 from googleapiclient.errors import HttpError
 
-SCRIPT_DIR = os.path.dirname(os.path.realpath(__file__))
-CLOUD_STORAGE_GOOGLE_SECRET = os.path.join(SCRIPT_DIR, "client_secret.json")
-CLOUD_STORAGE_GOOGLE_SCOPE = "https://www.googleapis.com/auth/drive",
-CLOUD_STORAGE_GOOGLE_APP_NAME = "Drive API Python Quickstart"
+from django.conf import settings
+
+try:
+    FileNotFoundError
+except NameError:
+    FileNotFoundError = IOError
+
+
+CLOUD_STORAGE_GOOGLE_SECRET = settings.CLOUD_STORAGE_GOOGLE_SECRET
+CLOUD_STORAGE_GOOGLE_SCOPE = settings.CLOUD_STORAGE_GOOGLE_SCOPE
+CLOUD_STORAGE_GOOGLE_APP_NAME = settings.CLOUD_STORAGE_GOOGLE_APP_NAME
+
 
 class ServiceSingleton:
     __single = None
@@ -54,8 +61,9 @@ class ServiceSingleton:
     def getCredentials(self, clientSecretFile=None, scope=None,
                        appName=None, flags=None):
         # get or create .credentials in app dir
-        credentialDir = os.path.join(SCRIPT_DIR, ".credentials")
-        os.makedirs(credentialDir, exist_ok=True)
+        credentialDir = os.path.join(settings.BASE_DIR, ".credentials")
+        if not os.path.exists(credentialDir):
+            os.makedirs(credentialDir)
 
         # get credential
         credentialPath = os.path.join(credentialDir,
@@ -85,7 +93,7 @@ service = ServiceSingleton.getSingleton().service
 
 def handleHttpError(error):
     if error.resp.status == 404:
-        raise FileNotFoundError(str(e))
+        raise FileNotFoundError(str(error))
     else:
         raise error
 
