@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11261 2018-11-15 19:36:42Z Lavender $
+# $Id: __init__.py 11277 2018-11-29 07:20:01Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-11-16 03:36:42 +0800 (Fri, 16 Nov 2018) $
-# $Revision: 11261 $
+# $Date: 2018-11-29 16:20:01 +0900 (週四, 29 十一月 2018) $
+# $Revision: 11277 $
 
 import os
 import sys
@@ -38,6 +38,8 @@ from oscar import get_core_apps
 from oscar import OSCAR_MAIN_TEMPLATE_DIR
 
 from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext as _2
+from django.core.urlresolvers import reverse
 
 CKEDITOR_CONFIGS = {
     'default': {
@@ -315,6 +317,12 @@ def attachSettings(settingsDict, enablePaypal=False):
             'access_fn': \
                 lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
+        ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
+            'label': _('ECPay logistic transactions'),
+            'url_name': 'ecpayLogisticTransaction',
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+        })
     if allpayEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('AllPay transactions'),
@@ -355,6 +363,57 @@ def attachSettings(settingsDict, enablePaypal=False):
     update(settingsDict, DJANGO_CKEDITOR_CONF)
     #=========================================================================
 
+    #=========================================================================
+    # Django order status settings
+    needShipping = False
+    if 'IUNO_SHOP_NEED_SHIPPING' in settingsDict:
+        needShipping = settingsDict['IUNO_SHOP_NEED_SHIPPING']
+    """
+    ADDING_OSCAR_ORDER_STATUS = {
+        'OSCAR_INITIAL_ORDER_STATUS': _('Order pending'),
+        'OSCAR_INITIAL_LINE_STATUS': '-',
+        'OSCAR_ORDER_STATUS_PIPELINE': {
+            _('Order pending'): \
+                (_('Order being processed'), _('Order cancelled'),),
+            _('Order being processed'): \
+                (_('Order complete'), _('Order cancelled'),),
+            _('Order cancelled'): (),
+            _('Order complete'): (),
+            _('Order return'): (_('Order return complete'),),
+            _('Order return complete'): (),
+        }
+    }
+    """
+    if needShipping:
+        ADDING_OSCAR_ORDER_STATUS = {
+            'OSCAR_INITIAL_ORDER_STATUS': u'等待處理中',
+            'OSCAR_INITIAL_LINE_STATUS': '-',
+            'OSCAR_ORDER_STATUS_PIPELINE': {
+                u'等待處理中': \
+                    (u'商品送貨中', u'訂單取消', u'測試用訂單'),
+                u'商品送貨中': \
+                    (u'完成訂單', u'訂單取消', u'測試用訂單'),
+                u'訂單取消': (u'測試用訂單', ),
+                u'完成訂單': (u'測試用訂單', ),
+
+                u'商品退貨中': (u'商品退貨中',),
+                u'測試用訂單': (u'等待處理中',),
+            }
+        }
+    else:
+        ADDING_OSCAR_ORDER_STATUS = {
+            'OSCAR_INITIAL_ORDER_STATUS': u'完成訂單',
+            'OSCAR_INITIAL_LINE_STATUS': '-',
+            'OSCAR_ORDER_STATUS_PIPELINE': {
+                u'完成訂單': (u'測試用訂單', ),
+                u'測試用訂單': (u'完成訂單',),
+            }
+        }
+
+    update(settingsDict, ADDING_OSCAR_ORDER_STATUS)
+    
+    #=========================================================================
+    
 
 def attachShopURLs(settings, urlpatterns):
     """
@@ -422,6 +481,16 @@ def attachShopURLs(settings, urlpatterns):
                 staff_member_required(
                     views.ECPayTransactionListView.as_view()),
                 name='ecpayTransaction'),
+            url(r'^dashboard/ecpaylogistic/transaction/', 
+                staff_member_required(
+                    views.ECPayLogisticTransactionListView.as_view()),
+                name='ecpayLogisticTransaction'),
+            url(r'^shop/ecpaylogistic/reply/', 
+                views.ECPayServerReplyView.as_view(),
+                name='ecpayLogisticReply'),
+            url(r'^shop/ecpaylogistic/(?P<orderNumber>[\w-]*)/return/', 
+                views.ECPayLogisticreturnView.as_view(),
+                name='ecpayLogisticReturn'),
         )
     if allpayEnable:
         urlpatterns += patterns('',
@@ -670,12 +739,17 @@ def buildAPIForm(submission, request, apiName):
             'TradeDesc' : settings.OSCAR_SHOP_NAME, 
             'Remark' : settings.OSCAR_SHOP_NAME,
         }
+        if submission['shipping_address']:
+            needExtraData = False
+        else:
+            needExtraData = True
 
         context = Context({
             'apiUrl': apiUrl,
             'chantID': settings.ECPAY_API_MERCHANT_ID,
             'subTypes': subTypes,
             'returnUrl': returnUrl,
+            'needExtraData': needExtraData,
             'extraData': json.dumps(
                 data, ensure_ascii=False, default=str).replace("\"", "&quot;"),
         })
@@ -688,7 +762,8 @@ def buildAPIForm(submission, request, apiName):
         subType = request.POST.get("LogisticsSubType")
         extra = request.POST.get("ExtraData")
 
-        # 防呆
+        # 防呆 or submission 內會有地址資料
+        print submission['shipping_address']
         splitData = extra.split(",")
         name = splitData[1][len("name="):]
         phone = splitData[0][len("phone="):]
@@ -729,7 +804,7 @@ def buildAPIForm(submission, request, apiName):
             "ReceiverName": name, 
             "ReceiverCellPhone": phone, 
             
-            "ServerReplyURL": "http://127.0.0.1:8000/posttest/", # 隨時接訂單資訊的 URL
+            "ServerReplyURL": reverse("ecpayLogisticReply"), # 隨時接訂單資訊的 URL
             "ClientReplyURL": returnUrl,               
         }
         
