@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11261 2018-11-15 19:36:42Z Lavender $
+# $Id: views.py 11277 2018-11-29 07:20:01Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,17 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-11-16 03:36:42 +0800 (Fri, 16 Nov 2018) $
-# $Revision: 11261 $ 
+# $Date: 2018-11-29 16:20:01 +0900 (週四, 29 十一月 2018) $
+# $Revision: 11277 $ 
 
 import json
 import logging
 import hashlib
+import urllib
+
+from collections import OrderedDict
+
+import requests
 
 from lxml import etree
 from django.shortcuts import render
@@ -39,7 +44,9 @@ from Iuppiter.Encoding import utf8
 from Iuno.shop import forms
 from Iuno.shop import buildAPIForm
 from Iuno.shop.models import (
-    ECPayTrade, AllPayTrade, SpgatewayTrade, CathaybkCreditTrade)
+    ECPayTrade, AllPayTrade, SpgatewayTrade, CathaybkCreditTrade,
+    ECPayLogisticTrade)
+from Iuno.shop.Util import createCheckValue
 
 _PaymentDetailsView = get_class('checkout.views', 'PaymentDetailsView')
 
@@ -182,6 +189,194 @@ def download_selected_orders(self, request, orders):
 
 OrderListView.download_selected_orders = download_selected_orders
 
+from datetime import timedelta
+from decimal import Decimal as D
+from decimal import ROUND_UP
+
+from oscar.apps.dashboard.views import IndexView
+from oscar.core.compat import get_user_model
+from django.db.models import Avg, Count, Sum
+from django.utils.timezone import now
+
+StockAlert = get_model('partner', 'StockAlert')
+Line = get_model('order', 'Line')
+User = get_user_model()
+
+def get_hourly_report(self, hours=24, segments=10):
+    """
+    Get report of order revenue split up in hourly chunks. A report is
+    generated for the last *hours* (default=24) from the current time.
+    The report provides ``max_revenue`` of the hourly order revenue sum,
+    ``y-range`` as the labeling for the y-axis in a template and
+    ``order_total_hourly``, a list of properties for hourly chunks.
+    *segments* defines the number of labeling segments used for the y-axis
+    when generating the y-axis labels (default=10).
+    """
+    # Get datetime for 24 hours agao
+    time_now = now().replace(minute=0, second=0)
+    start_time = time_now - timedelta(hours=hours - 1)
+
+    # query all OrderNote
+    orders = Order.objects.exclude(status=u'測試用訂單')
+    orders_last_day = orders.filter(date_placed__gt=start_time)
+
+    order_total_hourly = []
+    for hour in range(0, hours, 2):
+        end_time = start_time + timedelta(hours=2)
+        hourly_orders = orders_last_day.filter(date_placed__gt=start_time,
+                                                date_placed__lt=end_time)
+        total = hourly_orders.aggregate(
+            Sum('total_incl_tax')
+        )['total_incl_tax__sum'] or D('0.0')
+        order_total_hourly.append({
+            'end_time': end_time,
+            'total_incl_tax': total
+        })
+        start_time = end_time
+
+    max_value = max([x['total_incl_tax'] for x in order_total_hourly])
+    divisor = 1
+    while divisor < max_value / 50:
+        divisor *= 10
+    max_value = (max_value / divisor).quantize(D('1'), rounding=ROUND_UP)
+    max_value *= divisor
+    if max_value:
+        segment_size = (max_value) / D('100.0')
+        for item in order_total_hourly:
+            item['percentage'] = int(item['total_incl_tax'] / segment_size)
+
+        y_range = []
+        y_axis_steps = max_value / D(str(segments))
+        for idx in reversed(range(segments + 1)):
+            y_range.append(idx * y_axis_steps)
+    else:
+        y_range = []
+        for item in order_total_hourly:
+            item['percentage'] = 0
+
+    ctx = {
+        'order_total_hourly': order_total_hourly,
+        'max_revenue': max_value,
+        'y_range': y_range,
+    }
+    return ctx
+
+def get_stats(self):
+    datetime_24hrs_ago = now() - timedelta(hours=24)
+
+    # query all OrderNote
+    orders = Order.objects.exclude(status=u'測試用訂單')
+    orders_last_day = orders.filter(date_placed__gt=datetime_24hrs_ago)
+
+    open_alerts = StockAlert.objects.filter(status=StockAlert.OPEN)
+    closed_alerts = StockAlert.objects.filter(status=StockAlert.CLOSED)
+
+    total_lines_last_day = Line.objects.filter(
+        order__in=orders_last_day).count()
+    stats = {
+        'total_orders_last_day': orders_last_day.count(),
+        'total_lines_last_day': total_lines_last_day,
+
+        'average_order_costs': orders_last_day.aggregate(
+            Avg('total_incl_tax')
+        )['total_incl_tax__avg'] or D('0.00'),
+
+        'total_revenue_last_day': orders_last_day.aggregate(
+            Sum('total_incl_tax')
+        )['total_incl_tax__sum'] or D('0.00'),
+
+        'hourly_report_dict': self.get_hourly_report(hours=24),
+        'total_customers_last_day': User.objects.filter(
+            date_joined__gt=datetime_24hrs_ago,
+        ).count(),
+
+        'total_open_baskets_last_day': self.get_open_baskets({
+            'date_created__gt': datetime_24hrs_ago
+        }).count(),
+
+        'total_products': Product.objects.count(),
+        'total_open_stock_alerts': open_alerts.count(),
+        'total_closed_stock_alerts': closed_alerts.count(),
+
+        'total_site_offers': self.get_active_site_offers().count(),
+        'total_vouchers': self.get_active_vouchers().count(),
+        'total_promotions': self.get_number_of_promotions(),
+
+        'total_customers': User.objects.count(),
+        'total_open_baskets': self.get_open_baskets().count(),
+        'total_orders': orders.count(),
+        'total_lines': Line.objects.count(),
+        'total_revenue': orders.aggregate(
+            Sum('total_incl_tax')
+        )['total_incl_tax__sum'] or D('0.00'),
+
+        'order_status_breakdown': orders.order_by(
+            'status'
+        ).values('status').annotate(freq=Count('id'))
+    }
+    return stats
+
+IndexView.get_stats = get_stats
+IndexView.get_hourly_report = get_hourly_report
+
+from django.core.mail import send_mail
+from des.models import DynamicEmailConfiguration
+from django.contrib.sites.models import Site
+from oscar.apps.order.processing import EventHandler
+
+def handle_order_status_change(self, order, new_status, note_msg=None):
+    """
+    Handle a requested order status change
+
+    This method is not normally called directly by client code.  The main
+    use-case is when an order is cancelled, which in some ways could be
+    viewed as a shipping event affecting all lines.
+    """
+    order.set_status(new_status)
+    
+    if new_status == u'商品送貨中':
+        try:
+            temp = get_template(
+                'shop/customer/emails/BeingProcessedSubject.txt')
+            ctx = Context({
+                "order": order,
+                "site": Site.objects.get(id=settings.SITE_ID)
+            })
+            subject = temp.render(ctx)
+            
+            temp = get_template('shop/customer/emails/BeingProcessedBody.html')
+            htmlContent = temp.render(ctx)
+                        
+            temp = get_template('shop/customer/emails/BeingProcessedBody.txt')
+            txtContent = temp.render(ctx)
+            
+            if order.user:
+                email = order.user.email
+            else:
+                email = order.guest_email
+                                
+            success = send_mail(
+                subject,
+                txtContent,
+                DynamicEmailConfiguration.objects.get().from_email,
+                [email,],
+                html_message=htmlContent,
+                fail_silently=False,
+            )
+                                
+            if success:
+                logger.info("Send order email success: %s" % email)
+            else:
+                logger.error("Send order email fail: %s" % email)
+        except Exception as e:
+            logger.error("Error Send order email: %s" % e)
+    
+    if note_msg:
+        self.create_note(order, note_msg)
+
+EventHandler.handle_order_status_change = handle_order_status_change
+
+# ------------------------------------------------------------------------------
 # /cathaybk/preview/
 # /cathaybk-credit/checkxml/
 @csrf_exempt
@@ -474,17 +669,59 @@ class SuccessResponseView2(_PaymentDetailsView):
                 self.merchantTradeNo = request.POST.get('MerchantTradeNo')
                 index = self.merchantTradeNo.find('BASKETID')
                 self.basketId = int(self.merchantTradeNo[index + 8:])
+
+                self.merchantID = request.POST.get('MerchantID')
+                self.rtnCode = request.POST.get('RtnCode')
+                self.rtnMsg = request.POST.get('RtnMsg')
                 
+                self.updateStatusDate = request.POST.get('UpdateStatusDate')
+                self.receiverName = request.POST.get('ReceiverName')
+                self.receiverCellPhone = request.POST.get('ReceiverCellPhone')
+                self.receiverEmail = request.POST.get('ReceiverEmail')
+                self.logisticsType = request.POST.get('LogisticsType')
+                self.logisticsSubType = request.POST.get('LogisticsSubType')
+
+                self.paymentNo = request.POST.get('CVSPaymentNo')
+                self.validationNo = request.POST.get('CVSValidationNo')
+                
+                # error
+                if self.rtnMsg == 'ERROR':
+                    msg = _(
+                        "There was an error in the payment. Please try again.")
+                    messages.error(self.request, msg)
+                    logger.error(
+                        '%s API ERROR: %s' % (self.apiName, request.POST))
+                    return redirect('checkout:payment-details')
+
                 # record
+                """
                 for f in self.request.POST:
                     print "%s: %s" % (f, self.request.POST[f])
+                """
+                logisticTrade = ECPayLogisticTrade.objects.create(
+                    tradeNo=self.tradeNo,
+                    tradeAmt=int(self.tradeAmt),
+                    merchantId=self.merchantID,
+                    merchantTradeNo=self.merchantTradeNo,
+                    rtnCode=self.rtnCode,
+                    rtnMsg=self.rtnMsg,
+                    tradeDate=self.updateStatusDate.replace('/', '-'),
+                    updateStatusDate=self.updateStatusDate.replace('/', '-'),
+                    receiverName=self.receiverName,
+                    receiverCellPhone=self.receiverCellPhone,
+                    receiverEmail=self.receiverEmail,
+                    logisticsType=self.logisticsType,
+                    logisticsSubType=self.logisticsSubType,
+                    paymentNo=self.paymentNo,
+                    validationNo=self.validationNo,
+                )
                 
 
             return self.handle_place_order_submission(request)
         except Exception as e:
             # return msg
             logger.error(str(e))
-            raise
+            
             # if payment success
             msg1 = _("There was an except error in the payment."
                      " We have notified the administrator to deal with refund.")
@@ -581,25 +818,220 @@ class SuccessResponseView2(_PaymentDetailsView):
         self.add_payment_event('Settled', tradeAmt,
                                reference=tradeNo)
 
+class ECPayLogisticreturnView(generic.View):
+
+    http_method_names = ['get', 'post',]
+
+    def get(self, request, *args, **kwargs):
+        orderNumber = kwargs.get('orderNumber')
+        order = get_object_or_404(Order, number=orderNumber)
+        source = get_object_or_404(
+            Source, order=order, source_type__name='ecpay_logistic')
+        trade = get_object_or_404(ECPayLogisticTrade, tradeNo=source.reference)
+        
+        return render(
+            request, 
+            "shop/payment/EcpayReturn.html",
+            {
+                'order': order,
+                'trade': trade,
+            }
+        )
+
+    def post(self, request, *args, **kwargs):
+        orderNumber = kwargs.get('orderNumber')
+        order = get_object_or_404(Order, number=orderNumber)
+        source = get_object_or_404(
+            Source, order=order, source_type__name='ecpay_logistic')
+        trade = get_object_or_404(ECPayLogisticTrade, tradeNo=source.reference)
+        """
+        if trade.rtnMerchantTradeNo:
+            messages.error(self.request, u"已送出退貨訊息")
+            return redirect('customer:order-list')
+        """
+        data = {
+            'MerchantID': trade.merchantId,
+            'ServerReplyURL': reverse("ecpayLogisticReply"),
+            'GoodsAmount': trade.tradeAmt,
+            #'GoodsName': "Reference ",
+            'ServiceType': 4, # 退貨不付款
+            'SenderName': trade.receiverName,
+            'SenderPhone': trade.receiverCellPhone,
+            'AllPayLogisticsID': trade.tradeNo,
+        }
+
+        apiUrls = {
+            "FAMI": {
+                "stage": "https://logistics-stage.ecpay.com.tw/express/ReturnCVS",
+                "production": "https://logistics-stage.ecpay.com.tw/express/ReturnCVS", 
+            },
+            "UNIMART": {
+                "stage": "https://logistics-stage.ecpay.com.tw/express/ReturnUniMartCVS",
+                "production": "https://logistics.ecpay.com.tw/express/ReturnUniMartCVS", 
+            },
+            "HILIFE": {
+                "stage": "https://logistics-stage.ecpay.com.tw/express/ReturnHiLifeCVS",
+                "production": "https://logistics.ecpay.com.tw/express/ReturnHiLifeCVS", 
+            },
+        }
+
+        if settings.ECPAY_SANDBOX_MODE:
+            apiUrl = apiUrls[trade.logisticsSubType]["stage"]
+        else:
+            apiUrl = apiUrls[trade.logisticsSubType]["production"]
+
+        data["CheckMacValue"] = createCheckValue(data)
+
+        res = requests.post(apiUrl, data=data)
+
+        if not "ErrorMessage" in res.text:
+            messages.success(self.request, u"成功送出退貨訊息")
+            rtnMerchantTradeNo = res.text.split("|")[0]
+            rtnOrderNo = res.text.split("|")[1]
+
+            trade.rtnMerchantTradeNo = rtnMerchantTradeNo 
+            trade.rtnOrderNo = rtnOrderNo
+            trade.rtnMsg = u"已送出退貨資料"
+            trade.rtnCode = 100 # 固定
+            trade.save()
+            
+            order.status = "Order return"
+            order.save()
+
+            return redirect('customer:order-list')
+        else:
+            messages.error(self.request, u"送出退貨訊息失敗")
+            return redirect('customer:order-list')
+
+
+class ECPayServerReplyView(generic.View):
+
+    http_method_names = ['get', 'post',]
+
+    @csrf_exempt
+    def dispatch(self, request, *args, **kwargs):
+        return super(ECPayServerReplyView, self).dispatch(
+            request, *args, **kwargs)
+
+    def get(self, request, *args, **kwargs):
+        return render("|ErrorMessage")
+
+    def post(self, request, *args, **kwargs):
+        # data 
+        try:
+            self.tradeNo = request.POST.get('AllPayLogisticsID')
+            self.tradeAmt = request.POST.get('GoodsAmount')
+
+            self.merchantTradeNo = request.POST.get('MerchantTradeNo')
+
+            self.merchantID = request.POST.get('MerchantID')
+            self.rtnCode = request.POST.get('RtnCode')
+            self.rtnMsg = request.POST.get('RtnMsg')
+            
+            self.updateStatusDate = request.POST.get('UpdateStatusDate')
+            self.receiverName = request.POST.get('ReceiverName')
+            self.receiverCellPhone = request.POST.get('ReceiverCellPhone')
+            self.receiverEmail = request.POST.get('ReceiverEmail')
+            self.logisticsType = request.POST.get('LogisticsType')
+            self.logisticsSubType = request.POST.get('LogisticsSubType')
+
+            self.rtnMerchantTradeNo = request.POST.get('RtnMerchantTradeNo')
+
+            if self.rtnMerchantTradeNo:
+                logisticTrade = ECPayLogisticTrade.objects.filter(
+                    tradeNo=self.tradeNo).update(
+                        rtnCode=self.rtnCode,
+                        rtnMsg=self.rtnMsg,
+                        updateStatusDate=self.updateStatusDate.replace(
+                            '/', '-'),
+                )
+                return HttpResponse("1|OK")
+            else:
+                index = self.merchantTradeNo.find('BASKETID')
+                self.basketId = int(self.merchantTradeNo[index + 8:])
+
+                order = Order.objects.get(basket=self.basketId)
+
+                if self.rtnCode in ['2030', '3024', '2063', '3018']:
+                    order.status = 'Order being processed'
+                elif self.rtnCode in ['2067', '3022']:
+                    order.status = 'Order complete'
+                elif self.rtnCode in ['2074', '3020']:
+                    order.status = 'Order return'
+                else:
+                    return HttpResponse("|ErrorMessage")
+                order.save()
+
+                logisticTrade = ECPayLogisticTrade.objects.filter(
+                    tradeNo=self.tradeNo).update(
+                        tradeAmt=int(self.tradeAmt),
+                        merchantId=self.merchantID,
+                        merchantTradeNo=self.merchantTradeNo,
+                        rtnCode=self.rtnCode,
+                        rtnMsg=self.rtnMsg,
+                        updateStatusDate=self.updateStatusDate.replace('/', '-'),
+                        receiverName=self.receiverName,
+                        receiverCellPhone=self.receiverCellPhone,
+                        receiverEmail=self.receiverEmail,
+                        logisticsType=self.logisticsType,
+                        logisticsSubType=self.logisticsSubType,
+                )
+
+                return HttpResponse("1|OK")
+        except Exception as e:
+            logger.error(str(e))
+            return HttpResponse("|ErrorMessage")
+
+
+
+
+
 class ECPayTransactionListView(generic.ListView):
     model = ECPayTrade
     template_name = 'shop/payment/dashboard/ECPay.html'
     context_object_name = 'transactions'
 
+    def get_queryset(self):
+        return super(
+            ECPayTransactionListView, self).get_queryset().order_by('-id')
+
 class AllPayTransactionListView(generic.ListView):
     model = AllPayTrade
     template_name = 'shop/payment/dashboard/AllPay.html'
     context_object_name = 'transactions'
 
+    def get_queryset(self):
+        return super(
+            AllPayTransactionListView, self).get_queryset().order_by('-id')
+
 class SpgatewayTransactionListView(generic.ListView):
     model = SpgatewayTrade
     template_name = 'shop/payment/dashboard/Spgateway.html'
     context_object_name = 'transactions'
 
+    def get_queryset(self):
+        return super(
+            SpgatewayTransactionListView, self).get_queryset().order_by('-id')
+
 class CathaybkCreditTransactionListView(generic.ListView):
     model = CathaybkCreditTrade
     template_name = 'shop/payment/dashboard/CathayCredit.html'
     context_object_name = 'transactions'
+
+    def get_queryset(self):
+        return super(
+            CathaybkCreditTransactionListView, self
+            ).get_queryset().order_by('-id')
+
+class ECPayLogisticTransactionListView(generic.ListView):
+    model = ECPayLogisticTrade
+    template_name = 'shop/payment/dashboard/ECPayLogistic.html'
+    context_object_name = 'transactions'
+
+    def get_queryset(self):
+        return super(
+            ECPayLogisticTransactionListView, self
+            ).get_queryset().order_by('-id')
     
 # https://code.nuwainfo.com/trac/phantasos/ticket/589#ticket
 from oscar.apps.dashboard.catalogue import tables
