@@ -22,6 +22,10 @@ from dateutil import parser
 
 from Iuno.cloud.storage import gos as os
 
+try:
+    FileNotFoundError
+except NameError:
+    FileNotFoundError = IOError
 
 class GosTest(unittest.TestCase):
     TEST_FOLDER = "GosTest"
